@@ -1,9 +1,9 @@
 #include <iostream>
 #include <glibmm.h>
+#include "common/nmv-initializer.h"
+#include "common/nmv-safe-ptr-utils.h"
+#include "common/nmv-dynamic-module.h"
 #include "nmv-i-debugger.h"
-#include "nmv-initializer.h"
-#include "nmv-safe-ptr-utils.h"
-#include "nmv-dynamic-module.h"
 
 using namespace nemiver;
 using namespace nemiver::common ;
@@ -29,8 +29,11 @@ void
 on_stopped_signal (const UString &a_reason,
                    bool a_has_frame,
                    const IDebugger::Frame &a_frame,
-                   int a_thread_id)
+                   int a_thread_id,
+                   const UString &a_cookie)
 {
+    if (a_cookie.empty ()) {}
+
     std::cout << "stopped, reason: " << a_reason << " " ;
     if (a_has_frame) {
         std::cout << "in frame: " << a_frame.function_name () ;
@@ -38,14 +41,19 @@ on_stopped_signal (const UString &a_reason,
     std::cout << "thread-id: '" << a_thread_id << "'\n" ;
 }
 void
-on_current_frame_signal (const IDebugger::Frame &a_frame)
+on_current_frame_signal (const IDebugger::Frame &a_frame, const UString &a_cookie)
 {
+    if (a_cookie.empty ()) {}
+
     gv_cur_frame = a_frame.level ();
 }
 
 void
-on_frames_listed_signal (const std::vector<IDebugger::Frame> &a_frames)
+on_frames_listed_signal (const std::vector<IDebugger::Frame> &a_frames,
+                         const UString &a_cookie)
 {
+    if (a_cookie.empty ()) {}
+
     std::cout << "frame stack list: \n" ;
     vector<IDebugger::Frame>::size_type i = 0 ;
     for (i = 0 ; i < a_frames.size () ; ++i) {
@@ -63,9 +71,10 @@ on_frames_listed_signal (const std::vector<IDebugger::Frame> &a_frames)
 
 void
 on_frames_params_listed_signal
-    (const std::map< int, std::list<IDebugger::VariableSafePtr> >& a_frame_params)
+    (const std::map< int, std::list<IDebugger::VariableSafePtr> >& a_frame_params,
+     const UString &a_cookie)
 {
-    if (a_frame_params.empty ()) {}
+    if (a_frame_params.empty () || a_cookie.empty ()) {}
 }
 
 void
@@ -102,7 +111,7 @@ main (int a_argc, char *a_argv[])
 
         DynamicModuleManager module_manager ;
         IDebuggerSafePtr debugger =
-                    module_manager.load<IDebugger> ("gdbengine") ;
+                module_manager.load_iface<IDebugger> ("gdbengine", "IDebugger") ;
 
         debugger->set_event_loop_context (loop->get_context ()) ;
 
@@ -124,7 +133,7 @@ main (int a_argc, char *a_argv[])
         debugger->frames_listed_signal ().connect
             (sigc::ptr_fun (&on_frames_listed_signal)) ;
 
-        debugger->frames_params_listed_signal ().connect
+        debugger->frames_arguments_listed_signal ().connect
             (sigc::ptr_fun (&on_frames_params_listed_signal)) ;
 
         debugger->console_message_signal ().connect
